@@ -20,7 +20,7 @@
  *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 .pragma library
-.import QtQuick 2.0 as Quick
+.import QtQuick 2.6 as Quick
 
 var currentLevel
 var numberOfLevel
@@ -43,8 +43,6 @@ var randomMiss
 function start(items_, twoPlayer_) {
     items = items_
     currentLevel = 0
-    items.player1_score = 0
-    items.player2_score = 0
     twoPlayer = twoPlayer_
     initLevel()
 }
@@ -53,13 +51,15 @@ function stop() {
 }
 
 function initLevel() {
-
     numberOfLevel = twoPlayer ? 1 : weight.length
 
     items.bar.level = currentLevel + 1
 
     items.counter = 0
 
+    items.player2score.endTurn();
+    items.player1score.beginTurn();
+
     items.gameDone = false
     items.pieces.clear()
     for(var y = 0;  y < items.rows; y++) {
@@ -74,7 +74,6 @@ function initLevel() {
     else
         depthMax = 4
 
-
     if(currentLevel < 2)
         randomMiss = 1
     else if(currentLevel < 4)
@@ -100,6 +99,7 @@ function previousLevel() {
 }
 
 function reset() {
+    items.trigTuxMove.stop();
     items.drop.stop()    // stop animation
     items.pieces.clear() // Clear the board
     initLevel()
@@ -203,7 +203,6 @@ function getFreeStopFromBoard(column, board) {
 
 
 function alphabeta(depth, alpha, beta, player, board) {
-
     var value = evaluateBoard(player, player % 2 ? 2 : 1, board)
 
     if(depth === 0 || value === 100000 || value < -100000) {
@@ -211,7 +210,6 @@ function alphabeta(depth, alpha, beta, player, board) {
     }
 
     if(player === 2) {
-
         var scores = [];
 
         for(var c = 0; c < items.columns; c++) {
@@ -240,7 +238,6 @@ function alphabeta(depth, alpha, beta, player, board) {
         }
 
         return alpha;
-
     } else {
         for(var c = 0; c < items.columns; c++) {
 
@@ -261,7 +258,6 @@ function alphabeta(depth, alpha, beta, player, board) {
 }
 
 function doMove() {
-
     var board = getBoardFromModel()
 
     alphabeta(depthMax, -10000, 10000, 2, board)
@@ -464,7 +460,6 @@ function checkGameWon(currentPieceRow, currentPieceColumn) {
 }
 
 function continueGame() {
-
     items.pieces.set(currentPiece, {"stateTemp": items.counter++ % 2 ? "2": "1"})
 
     /* Update score if game won */
@@ -473,33 +468,48 @@ function continueGame() {
                         parseInt(currentPiece % items.columns))) {
             items.gameDone = true
             if(currentPlayer === "1") {
-                items.player1_score++
+                items.player1score.win();
+                items.player2score.endTurn();
             } else {
-                items.player2_score++
+                items.player2score.win();
+                items.player1score.endTurn();
             }
             items.bonus.good("flower")
-            items.bonus.isWin = false
         }
-
+        else {
+            if(currentPlayer === "2") {
+                items.player1score.beginTurn();
+                items.player2score.endTurn();
+            } else {
+                items.player2score.beginTurn();
+                items.player1score.endTurn();
+            }
+        }
     } else {
         if(checkGameWon(parseInt(currentPiece / items.columns),
                         parseInt(currentPiece % items.columns))) {
             items.gameDone = true
             if(currentPlayer === "1") {
-                items.player1_score++
+                items.player1score.win()
+                items.player2score.endTurn()
                 items.bonus.good("flower")
-                items.bonus.isWin = false
                 items.counter--
             } else {
-                items.player2_score++
+                items.player2score.win()
+                items.player1score.endTurn()
                 items.bonus.bad("flower")
             }
         }
         if(items.counter % 2) {
-            doMove()
+            items.player1score.endTurn()
+            items.player2score.beginTurn()
+            items.trigTuxMove.start()
         }
     }
     if(items.counter === 42) {
+        items.player1score.endTurn()
+        items.player2score.endTurn()
         items.bonus.bad("flower")
     }
 }
+
