@@ -20,7 +20,7 @@
  *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 .pragma library
-.import QtQuick 2.0 as Quick
+.import QtQuick 2.6 as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "engine.js" as Engine
 
@@ -238,6 +238,8 @@ function undo() {
         redo_stack.push(state.history[state.moveno - 1])
         state.jump_to_moveno(state.moveno - 1)
     }
+    // without it, you can't move again the same piece
+    Engine.p4_prepare(state)
     items.redo_stack = redo_stack
     refresh()
     items.positions = [] // Force a model reload
@@ -311,8 +313,9 @@ function clearAcceptMove() {
 function showPossibleMoves(from) {
     var result = Engine.p4_parse(state, state.to_play, 0, 0)
     clearAcceptMove()
+    var fromEngine = viewPosToEngine(from)
     for(var i=0; i < result.length; ++i) {
-        if(viewPosToEngine(from) == result[i][1]) {
+        if(fromEngine == result[i][1]) {
             var pos = engineToViewPos(result[i][2])
             items.squares.getSquareAt(pos)['acceptMove'] = true
         }
