@@ -21,7 +21,7 @@
  */
 
 .pragma library
-.import QtQuick 2.0 as Quick
+.import QtQuick 2.6 as Quick
 .import GCompris 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
@@ -136,6 +136,9 @@ function processKeyPress(text) {
     // Add the character to the already typed characters
     alreadyTypedLetters.push(text);
 
+    // add the typed character in the "Attempted characters" text field
+    createAttemptedText()
+
     // Get all the indices of this letter in the word
     var indices = [];
     for(var i = 0 ; i < currentWord.length ; i ++) {
@@ -200,6 +203,8 @@ function initSubLevel() {
     alreadyTypedLetters = new Array();
     currentWord = items.goodWord.translatedTxt;
     items.hidden.text = ""
+    createAttemptedText()
+
     for(var i = 0; i < currentWord.length ; ++ i) {
         if(currentWord[i] == " ") {
             items.hidden.text = items.hidden.text + " " + " "
@@ -209,6 +214,11 @@ function initSubLevel() {
     }
 }
 
+function createAttemptedText() {
+    alreadyTypedLetters.sort()
+    items.guessedText.text = qsTr("Attempted: %1").arg(alreadyTypedLetters.join(", "))
+}
+
 function nextSubLevel() {
     if( ++currentSubLevel >= maxSubLevel) {
         currentSubLevel = 0;
