@@ -293,7 +293,7 @@ void ActivityInfoTree::init()
     if(!QResource::registerResource(ApplicationInfo::getFilePath("activities.rcc")))
         qDebug() << "Failed to load the resource file activities.rcc";
 
-    if(QResource::registerResource(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) +
+    if(QResource::registerResource(ApplicationSettings::getInstance()->cachePath() +
                                    "/data2/" + QString("full-%1.rcc").arg(COMPRESSED_AUDIO)))
         qDebug() << "Registered the pre-download " << QString("full-%1.rcc").arg(COMPRESSED_AUDIO);
 
@@ -308,7 +308,7 @@ void ActivityInfoTree::filterBySearch(const QString& text)
     m_menuTree.clear();
     if(!text.trimmed().isEmpty()) {
         // perform search on each word entered in the searchField
-        QStringList wordsList = text.split(" ", QString::SkipEmptyParts);
+        QStringList wordsList = text.split(' ', QString::SkipEmptyParts);
         Q_FOREACH(const QString &searchTerm, wordsList) {
             const QString trimmedText = searchTerm.trimmed();
             for(const auto &activity: m_menuTreeFull) {
