@@ -1,4 +1,4 @@
-/* GCompris - ApplicationSettingsDefault.cpp
+/* GCompris - ApplicationInfo.cpp
  *
  * Copyright (C) 2014-2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
  *
@@ -55,12 +55,12 @@ ApplicationInfo::ApplicationInfo(QObject *parent): QObject(parent)
 #if defined(Q_OS_ANDROID)
     // Put android before checking linux/unix as it is also a linux
     m_platform = Android;
+#elif defined(Q_OS_MAC)
+    m_platform = MacOSX;
 #elif (defined(Q_OS_LINUX) || defined(Q_OS_UNIX))
     m_platform = Linux;
 #elif defined(Q_OS_WIN)
     m_platform = Windows;
-#elif defined(Q_OS_MAC)
-    m_platform = MacOSX;
 #elif defined(Q_OS_IOS)
     m_platform = Ios;
 #elif defined(Q_OS_BLACKBERRY)
@@ -239,8 +239,6 @@ QString ApplicationInfo::getVoicesLocale(const QString &locale)
 QVariantList ApplicationInfo::localeSort(QVariantList list,
                                          const QString& locale) const
 {
-    QElapsedTimer timer;
-    timer.start();
     std::sort(list.begin(), list.end(),
               [&locale,this](const QVariant& a, const QVariant& b) {
         return (localeCompare(a.toString(), b.toString(), locale) < 0);
